@@ -34,12 +34,12 @@
 #' @export
 #' @name run_raven
 #' @examples
-#' \dontrun{
+#' \donttest{
 #'# save sound files
-#' library(warbleR) 
+#' library(NatureSounds) 
 #' data(list = c("Phae.long1", "Phae.long2", "Phae.long3", "Phae.long4"))
-#' writeWave(Phae.long1, file.path(tempdir(), "Phae.long1.wav"), extensible = FALSE)
-#' writeWave(Phae.long2, file.path(tempdir(), "Phae.long2.wav"), extensible = FALSE)
+#' tuneR::writeWave(Phae.long1, file.path(tempdir(), "Phae.long1.wav"), extensible = FALSE)
+#' tuneR::writeWave(Phae.long2, file.path(tempdir(), "Phae.long2.wav"), extensible = FALSE)
 #' 
 #' # here replace with the path where 'Raven' is install in your computer
 #' raven.path <- "PATH_TO_RAVEN_DIRECTORY_HERE" 
@@ -50,17 +50,8 @@
 #'  all.data = TRUE, path = tempdir())  
 #'  
 #' #getting all the data
-#' rav.dat<-run_raven(all.data = TRUE, raven.path = raven.path)
+#' rav.dat <- run_raven(all.data = TRUE, raven.path = raven.path)
 #' # View(rav.dat)
-#' 
-#' writeWave(Phae.long3, file.path(tempdir(), "Phae.long3.wav"), extensible = FALSE)
-#' writeWave(Phae.long4, file.path(tempdir(), "Phae.long4.wav"), extensible = FALSE)
-#' 
-#' # run function on all the wav files in the working directory 3 at the time
-#' run_raven(raven.path = raven.path, sound.files = list.files(pattern = "\\.wav$", 
-#' ignore.case = TRUE, path = tempdir()), at.the.time = 3, import = FALSE, 
-#' path = tempdir())
-#'   
 #' }
 #' 
 #' @author Marcelo Araya-Salas (\email{marceloa27@@gmail.com})
@@ -76,12 +67,18 @@ run_raven <- function(raven.path = NULL, sound.files = NULL, path = NULL, at.the
   
   if (is.null(raven.path))
     stop("Path to 'Raven' folder must be provided")  else
-      if (!dir.exists(raven.path)) stop("'raven.path' provided does not exist")
+      if (!dir.exists(raven.path)) stop("'raven.path' provided does not exist") else 
+        setwd(raven.path)
     
   # set progress bar back to original
   on.exit(pbapply::pboptions(type = .Options$pboptions$type), 
           add = TRUE)
-    
+  
+  # return to current wd on exit
+  cwd <- getwd()
+  on.exit(setwd(cwd), add = TRUE)
+  
+   
   if (!is.null(view.preset))
    {
     if (!any(view.preset %in% list.files(path = file.path(raven.path, "Presets/Sound Window")))) stop("'view.preset' provided not found")
